@@ -651,15 +651,12 @@ validateSelected <- function(selected, choices, inputId) {
 # generate options for radio buttons and checkbox groups (type = 'checkbox' or
 # 'radio')
 generateOptions <- function(inputId, choices, selected, inline, type = 'checkbox') {
-  # create tags for each of the options
-  ids <- paste0(inputId, seq_along(choices))
-
   # generate a list of <input type=? [checked] />
   options <- mapply(
-    ids, choices, names(choices),
-    FUN = function(id, value, name) {
+    choices, names(choices),
+    FUN = function(value, name) {
       inputTag <- tags$input(
-        type = type, name = inputId, id = id, value = value
+        type = type, name = inputId, value = value
       )
       if (value %in% selected)
         inputTag$attribs$checked <- "checked"
@@ -1146,14 +1143,14 @@ sliderInput <- function(inputId, label, min, max, value, step = NULL,
           'data-target-id'=inputId,
           'data-interval'=animate$interval,
           'data-loop'=animate$loop,
-          span(class = 'play', icon('play', lib = 'glyphicon')),
-          span(class = 'pause', icon('pause', lib = 'glyphicon'))
+          span(class = 'play', animate$playButton),
+          span(class = 'pause', animate$pauseButton)
         )
       )
     )
   }
 
-  dep <- htmlDependency("ionrangeslider", "2.0.2", c(href="shared/ionrangeslider"),
+  dep <- htmlDependency("ionrangeslider", "2.0.6", c(href="shared/ionrangeslider"),
     script = "js/ion.rangeSlider.min.js",
     stylesheet = c("css/normalize.css", "css/ion.rangeSlider.css",
                    "css/ion.rangeSlider.skinShiny.css")
@@ -1698,90 +1695,347 @@ verbatimTextOutput <- function(outputId) {
   textOutput(outputId, container = pre)
 }
 
-#' Create a image output element
+#' Create an plot or image output element
 #'
-#' Render a \link{renderImage} within an application page.
-#' @param outputId output variable to read the image from
-#' @param width Image width. Must be a valid CSS unit (like \code{"100\%"},
-#'   \code{"400px"}, \code{"auto"}) or a number, which will be coerced to a
-#'   string and have \code{"px"} appended.
-#' @param height Image height
-#' @inheritParams textOutput
-#' @return An image output element that can be included in a panel
-#' @examples
-#' # Show an image
-#' mainPanel(
-#'   imageOutput("dataImage")
-#' )
-#' @export
-imageOutput <- function(outputId, width = "100%", height="400px", inline=FALSE) {
-  style <- paste("width:", validateCssUnit(width), ";",
-    "height:", validateCssUnit(height))
-  container <- if (inline) span else div
-  container(id = outputId, class = "shiny-image-output", style = style)
-}
-
-#' Create an plot output element
+#' Render a \code{\link{renderPlot}} or \code{\link{renderImage}} within an
+#' application page.
 #'
-#' Render a \link{renderPlot} within an application page.
-#' @param outputId output variable to read the plot from
-#' @param width,height Plot width/height. Must be a valid CSS unit (like
+#' @section Interactive plots:
+#'
+#'   Plots and images in Shiny support mouse-based interaction, via clicking,
+#'   double-clicking, hovering, and brushing. When these interaction events
+#'   occur, the mouse coordinates will be sent to the server as \code{input$}
+#'   variables, as specified by \code{click}, \code{dblclick}, \code{hover}, or
+#'   \code{brush}.
+#'
+#'   For \code{plotOutput}, the coordinates will be sent scaled to the data
+#'   space, if possible. (At the moment, plots generated by base graphics
+#'   support this scaling, although plots generated by grid or ggplot2 do not.)
+#'   If scaling is not possible, the raw pixel coordinates will be sent. For
+#'   \code{imageOutput}, the coordinates will be sent in raw pixel coordinates.
+#'
+#' @param outputId output variable to read the plot/image from.
+#' @param width,height Image width/height. Must be a valid CSS unit (like
 #'   \code{"100\%"}, \code{"400px"}, \code{"auto"}) or a number, which will be
 #'   coerced to a string and have \code{"px"} appended. These two arguments are
 #'   ignored when \code{inline = TRUE}, in which case the width/height of a plot
 #'   must be specified in \code{renderPlot()}. Note that, for height, using
-#'   \code{"auto"} or \code{"100\%"} generally will not work as expected, because
-#'   of how height is computed with HTML/CSS.
-#' @param clickId If not \code{NULL}, the plot will send coordinates to the
-#'   server whenever it is clicked. This information will be accessible on the
-#'   \code{input} object using \code{input$}\emph{\code{clickId}}. The value
-#'   will be a named list or vector with \code{x} and \code{y} elements
-#'   indicating the mouse position in user units.
-#' @param hoverId If not \code{NULL}, the plot will send coordinates to the
-#'   server whenever the mouse pauses on the plot for more than the number of
-#'   milliseconds determined by \code{hoverTimeout}. This information will be
-#'   accessible on the \code{input} object using
-#'   \code{input$}\emph{\code{clickId}}. The value will be \code{NULL} if the
-#'   user is not hovering, and a named list or vector with \code{x} and \code{y}
-#'   elements indicating the mouse position in user units.
-#' @param hoverDelay The delay for hovering, in milliseconds.
-#' @param hoverDelayType The type of algorithm for limiting the number of hover
-#'   events. Use \code{"throttle"} to limit the number of hover events to one
-#'   every \code{hoverDelay} milliseconds. Use \code{"debounce"} to suspend
-#'   events while the cursor is moving, and wait until the cursor has been at
-#'   rest for \code{hoverDelay} milliseconds before sending an event.
+#'   \code{"auto"} or \code{"100\%"} generally will not work as expected,
+#'   because of how height is computed with HTML/CSS.
+#' @param click This can be \code{NULL} (the default), a string, or an object
+#'   created by the \code{\link{clickOpts}} function. If you use a value like
+#'   \code{"plot_click"} (or equivalently, \code{clickOpts(id="plot_click")}),
+#'   the plot will send coordinates to the server whenever it is clicked, and
+#'   the value will be accessible via \code{input$plot_click}. The value will
+#'   be a named list  with \code{x} and \code{y} elements indicating the mouse
+#'   position.
+#' @param dblclick This is just like the \code{click} argument, but for
+#'   double-click events.
+#' @param hover Similar to the \code{click} argument, this can be \code{NULL}
+#'   (the default), a string, or an object created by the
+#'   \code{\link{hoverOpts}} function. If you use a value like
+#'   \code{"plot_hover"} (or equivalently, \code{hoverOpts(id="plot_hover")}),
+#'   the plot will send coordinates to the server pauses on the plot, and the
+#'   value will be accessible via \code{input$plot_hover}. The value will be a
+#'   named list with \code{x} and \code{y} elements indicating the mouse
+#'   position. To control the hover time or hover delay type, you must use
+#'   \code{\link{hoverOpts}}.
+#' @param clickId Deprecated; use \code{click} instead. Also see the
+#'   \code{\link{clickOpts}} function.
+#' @param hoverId Deprecated; use \code{hover} instead. Also see the
+#'   \code{\link{hoverOpts}} function.
+#' @param hoverDelay Deprecated; use \code{hover} instead. Also see the
+#'   \code{\link{hoverOpts}} function.
+#' @param hoverDelayType Deprecated; use \code{hover} instead. Also see the
+#'   \code{\link{hoverOpts}} function.
+#' @param brush Similar to the \code{click} argument, this can be \code{NULL}
+#'   (the default), a string, or an object created by the
+#'   \code{\link{brushOpts}} function. If you use a value like
+#'   \code{"plot_brush"} (or equivalently, \code{brushOpts(id="plot_brush")}),
+#'   the plot will allow the user to "brush" in the plotting area, and will send
+#'   information about the brushed area to the server, and the value will be
+#'   accessible via \code{input$plot_brush}. Brushing means that the user will
+#'   be able to draw a rectangle in the plotting area and drag it around. The
+#'   value will be a named list with \code{xmin}, \code{xmax}, \code{ymin}, and
+#'   \code{ymax} elements indicating the brush area. To control the brush
+#'   behavior, use \code{\link{brushOpts}}.
 #' @inheritParams textOutput
 #' @note The arguments \code{clickId} and \code{hoverId} only work for R base
 #'   graphics (see the \pkg{\link{graphics}} package). They do not work for
 #'   \pkg{\link[grid:grid-package]{grid}}-based graphics, such as \pkg{ggplot2},
 #'   \pkg{lattice}, and so on.
-#' @return A plot output element that can be included in a panel
+#'
+#' @return A plot or image output element that can be included in a panel.
+#' @seealso For the corresponding server-side functions, see
+#'   \code{\link{renderPlot}} and  \code{\link{renderImage}}.
+#'
 #' @examples
-#' # Show a plot of the generated distribution
-#' mainPanel(
-#'   plotOutput("distPlot")
+#' # Only run these examples in interactive R sessions
+#' if (interactive()) {
+#'
+#' # A basic shiny app with a plotOutput
+#' shinyApp(
+#'   ui = fluidPage(
+#'     sidebarLayout(
+#'       sidebarPanel(
+#'         actionButton("newplot", "New plot")
+#'       ),
+#'       mainPanel(
+#'         plotOutput("plot")
+#'       )
+#'     )
+#'   ),
+#'   server = function(input, output) {
+#'     output$plot <- renderPlot({
+#'       input$newplot
+#'       # Add a little noise to the cars data
+#'       cars2 <- cars + rnorm(nrow(cars))
+#'       plot(cars2)
+#'     })
+#'   }
 #' )
+#'
+#'
+#' # A demonstration of clicking, hovering, and brushing
+#' shinyApp(
+#'   ui = basicPage(
+#'     fluidRow(
+#'       column(width = 4,
+#'         plotOutput("plot", height=300,
+#'           click = "plot_click",  # Equiv, to click=clickOpts(id="plot_click")
+#'           hover = hoverOpts(id = "plot_hover", delayType = "throttle"),
+#'           brush = brushOpts(id = "plot_brush")
+#'         ),
+#'         h4("Clicked points"),
+#'         tableOutput("plot_clickedpoints"),
+#'         h4("Brushed points"),
+#'         tableOutput("plot_brushedpoints")
+#'       ),
+#'       column(width = 4,
+#'         verbatimTextOutput("plot_clickinfo"),
+#'         verbatimTextOutput("plot_hoverinfo")
+#'       ),
+#'       column(width = 4,
+#'         wellPanel(actionButton("newplot", "New plot")),
+#'         verbatimTextOutput("plot_brushinfo")
+#'       )
+#'     )
+#'   ),
+#'   server = function(input, output, session) {
+#'     data <- reactive({
+#'       input$newplot
+#'       # Add a little noise to the cars data so the points move
+#'       cars + rnorm(nrow(cars))
+#'     })
+#'     output$plot <- renderPlot({
+#'       d <- data()
+#'       plot(d$speed, d$dist)
+#'     })
+#'     output$plot_clickinfo <- renderPrint({
+#'       cat("Click:\n")
+#'       str(input$plot_click)
+#'     })
+#'     output$plot_hoverinfo <- renderPrint({
+#'       cat("Hover (throttled):\n")
+#'       str(input$plot_hover)
+#'     })
+#'     output$plot_brushinfo <- renderPrint({
+#'       cat("Brush (debounced):\n")
+#'       str(input$plot_brush)
+#'     })
+#'     output$plot_clickedpoints <- renderTable({
+#'       # For base graphics, we need to specify columns, though for ggplot2,
+#'       # it's usually not necessary.
+#'       res <- nearPoints(data(), input$plot_click, "speed", "dist")
+#'       if (nrow(res) == 0)
+#'         return()
+#'       res
+#'     })
+#'     output$plot_brushedpoints <- renderTable({
+#'       res <- brushedPoints(data(), input$plot_brush, "speed", "dist")
+#'       if (nrow(res) == 0)
+#'         return()
+#'       res
+#'     })
+#'   }
+#' )
+#'
+#'
+#' # Demo of clicking, hovering, brushing with imageOutput
+#' # Note that coordinates are in pixels
+#' shinyApp(
+#'   ui = basicPage(
+#'     fluidRow(
+#'       column(width = 4,
+#'         imageOutput("image", height=300,
+#'           click = "image_click",
+#'           hover = hoverOpts(
+#'             id = "image_hover",
+#'             delay = 500,
+#'             delayType = "throttle"
+#'           ),
+#'           brush = brushOpts(id = "image_brush")
+#'         )
+#'       ),
+#'       column(width = 4,
+#'         verbatimTextOutput("image_clickinfo"),
+#'         verbatimTextOutput("image_hoverinfo")
+#'       ),
+#'       column(width = 4,
+#'         wellPanel(actionButton("newimage", "New image")),
+#'         verbatimTextOutput("image_brushinfo")
+#'       )
+#'     )
+#'   ),
+#'   server = function(input, output, session) {
+#'     output$image <- renderImage({
+#'       input$newimage
+#'
+#'       # Get width and height of image output
+#'       width  <- session$clientData$output_image_width
+#'       height <- session$clientData$output_image_height
+#'
+#'       # Write to a temporary PNG file
+#'       outfile <- tempfile(fileext = ".png")
+#'
+#'       png(outfile, width=width, height=height)
+#'       plot(rnorm(200), rnorm(200))
+#'       dev.off()
+#'
+#'       # Return a list containing information about the image
+#'       list(
+#'         src = outfile,
+#'         contentType = "image/png",
+#'         width = width,
+#'         height = height,
+#'         alt = "This is alternate text"
+#'       )
+#'     })
+#'     output$image_clickinfo <- renderPrint({
+#'       cat("Click:\n")
+#'       str(input$image_click)
+#'     })
+#'     output$image_hoverinfo <- renderPrint({
+#'       cat("Hover (throttled):\n")
+#'       str(input$image_hover)
+#'     })
+#'     output$image_brushinfo <- renderPrint({
+#'       cat("Brush (debounced):\n")
+#'       str(input$image_brush)
+#'     })
+#'   }
+#' )
+#'
+#' }
 #' @export
-plotOutput <- function(outputId, width = "100%", height="400px",
-                       clickId = NULL, hoverId = NULL, hoverDelay = 300,
-                       hoverDelayType = c("debounce", "throttle"), inline = FALSE) {
-  if (is.null(clickId) && is.null(hoverId)) {
-    hoverDelay <- NULL
-    hoverDelayType <- NULL
-  } else {
-    hoverDelayType <- match.arg(hoverDelayType)[[1]]
+imageOutput <- function(outputId, width = "100%", height="400px",
+                        click = NULL, dblclick = NULL,
+                        hover = NULL, hoverDelay = NULL, hoverDelayType = NULL,
+                        brush = NULL,
+                        clickId = NULL, hoverId = NULL,
+                        inline = FALSE) {
+
+  if (!is.null(clickId)) {
+    shinyDeprecated(
+      msg = paste("The 'clickId' argument is deprecated. ",
+                  "Please use 'click' instead. ",
+                  "See ?imageOutput or ?plotOutput for more information."),
+      version = "0.11.1"
+    )
+    click <- clickId
+  }
+
+  if (!is.null(hoverId)) {
+    shinyDeprecated(
+      msg = paste("The 'hoverId' argument is deprecated. ",
+                  "Please use 'hover' instead. ",
+                  "See ?imageOutput or ?plotOutput for more information."),
+      version = "0.11.1"
+    )
+    hover <- hoverId
+  }
+
+  if (!is.null(hoverDelay) || !is.null(hoverDelayType)) {
+    shinyDeprecated(
+      msg = paste("The 'hoverDelay'and 'hoverDelayType' arguments are deprecated. ",
+                  "Please use 'hoverOpts' instead. ",
+                  "See ?imageOutput or ?plotOutput for more information."),
+      version = "0.11.1"
+    )
+    hover <- hoverOpts(id = hover, delay = hoverDelay, delayType = hoverDelayType)
   }
 
   style <- if (!inline) {
     paste("width:", validateCssUnit(width), ";", "height:", validateCssUnit(height))
   }
 
+
+  # Build up arguments for call to div() or span()
+  args <- list(
+    id = outputId,
+    class = "shiny-image-output",
+    style = style
+  )
+
+  # Given a named list with options, replace names like "delayType" with
+  # "data-hover-delay-type" (given a prefix "hover")
+  formatOptNames <- function(opts, prefix) {
+    newNames <- paste("data", prefix, names(opts), sep = "-")
+    # Replace capital letters with "-" and lowercase letter
+    newNames <- gsub("([A-Z])", "-\\L\\1", newNames, perl = TRUE)
+    names(opts) <- newNames
+    opts
+  }
+
+  if (!is.null(click)) {
+    # If click is a string, turn it into clickOpts object
+    if (is.character(click)) {
+      click <- clickOpts(id = click)
+    }
+    args <- c(args, formatOptNames(click, "click"))
+  }
+
+  if (!is.null(dblclick)) {
+    if (is.character(dblclick)) {
+      dblclick <- clickOpts(id = dblclick)
+    }
+    args <- c(args, formatOptNames(dblclick, "dblclick"))
+  }
+
+  if (!is.null(hover)) {
+    if (is.character(hover)) {
+      hover <- hoverOpts(id = hover)
+    }
+    args <- c(args, formatOptNames(hover, "hover"))
+  }
+
+  if (!is.null(brush)) {
+    if (is.character(brush)) {
+      brush <- brushOpts(id = brush)
+    }
+    args <- c(args, formatOptNames(brush, "brush"))
+  }
+
   container <- if (inline) span else div
-  container(id = outputId, class = "shiny-plot-output", style = style,
-      `data-click-id` = clickId,
-      `data-hover-id` = hoverId,
-      `data-hover-delay` = hoverDelay,
-      `data-hover-delay-type` = hoverDelayType)
+  do.call(container, args)
+}
+
+#' @rdname imageOutput
+#' @export
+plotOutput <- function(outputId, width = "100%", height="400px",
+                       click = NULL, dblclick = NULL,
+                       hover = NULL, hoverDelay = NULL, hoverDelayType = NULL,
+                       brush = NULL,
+                       clickId = NULL, hoverId = NULL,
+                       inline = FALSE) {
+
+  # Result is the same as imageOutput, except for HTML class
+  res <- imageOutput(outputId, width, height, click, dblclick,
+                     hover, hoverDelay, hoverDelayType, brush,
+                     clickId, hoverId, inline)
+
+  res$attribs$class <- "shiny-plot-output"
+  res
 }
 
 #' Create a table output element
@@ -1834,11 +2088,11 @@ tableOutput <- function(outputId) {
 
 dataTableDependency <- list(
   htmlDependency(
-    "datatables", "1.10.4", c(href = "shared/datatables"),
+    "datatables", "1.10.5", c(href = "shared/datatables"),
     script = "js/jquery.dataTables.min.js"
   ),
   htmlDependency(
-    "datatables-bootstrap", "1.10.4", c(href = "shared/datatables"),
+    "datatables-bootstrap", "1.10.5", c(href = "shared/datatables"),
     stylesheet = c("css/dataTables.bootstrap.css", "css/dataTables.extra.css"),
     script = "js/dataTables.bootstrap.js"
   )
@@ -1847,6 +2101,9 @@ dataTableDependency <- list(
 #' @rdname tableOutput
 #' @export
 dataTableOutput <- function(outputId) {
+  shinyDeprecated(
+    'DT::dataTableOutput', old = 'shiny::dataTableOutput', version = '0.11.1'
+  )
   attachDependencies(
     div(id = outputId, class="shiny-datatable-output"),
     dataTableDependency
